==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/LDdist.R <==
###
#  This is a wrapper function for Dr. Albert Vernon Smith's c++ function 'getLDdist'.
###
"LDdist.geneSet" <- function( object, posVec, maxDist )
  {
    myrownames <- object@markerInfo$Name
    if(length(posVec)!=length(myrownames))
    { stop("number of markers is not equal to the length of 'posVec'!\n") }

    mycolnames <- myrownames
 
    ped<-geneSet2Ped2(object)

    tmp<-getLDdist(ped$ped, posVec, maxDist, ped$columns, pooling.threshold=0.1, 
                   iprint=FALSE)
    D<-tmp$DMat
    rownames(D) <- myrownames 
    colnames(D) <- mycolnames

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <-  myrownames
    colnames(Dprime) <- mycolnames

    corr<-tmp$rMat
    rownames(corr) <- myrownames
    colnames(corr) <- mycolnames

    r.2<-tmp$r2Mat
    rownames(r.2) <- myrownames
    colnames(r.2) <- mycolnames

    chisq<-tmp$chisqMat
    rownames(chisq) <- myrownames
    colnames(chisq) <- mycolnames

    p.value<-tmp$pvalMat
    rownames(p.value) <- myrownames
    colnames(p.value) <- mycolnames

    nobs<-tmp$nMat
    rownames(nobs) <- myrownames
    colnames(nobs) <- mycolnames

    LOD<-tmp$LODMat
    rownames(LOD) <- myrownames
    colnames(LOD) <- mycolnames

    retval <- new("LDdist",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LDdist", function(object, posVec, maxDist,...)
           standardGeneric("LDdist"))

setMethod("LDdist", "geneSet", LDdist.geneSet)

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/LDdist.R <==
###
#  This is a wrapper function for Dr. Albert Vernon Smith's c++ function 'getLDdist'.
###
"LDdist.geneSet" <- function( object, posVec, maxDist, pooling.threshold=0.1, 
  founderOnly=FALSE, quiet=TRUE )
  {
    myrownames <- object@markerInfo$Name
    if(length(posVec)!=length(myrownames))
    { stop("number of markers is not equal to the length of 'posVec'!\n") }

    mycolnames <- myrownames
 
    tmp<-getLDdist(object, posVec, maxDist,  pooling.threshold, 
                   founderOnly, quiet)
    D<-tmp$DMat
    rownames(D) <- myrownames 
    colnames(D) <- mycolnames

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <-  myrownames
    colnames(Dprime) <- mycolnames

    corr<-tmp$rMat
    rownames(corr) <- myrownames
    colnames(corr) <- mycolnames

    r.2<-tmp$r2Mat
    rownames(r.2) <- myrownames
    colnames(r.2) <- mycolnames

    chisq<-tmp$chisqMat
    rownames(chisq) <- myrownames
    colnames(chisq) <- mycolnames

    p.value<-tmp$pvalMat
    rownames(p.value) <- myrownames
    colnames(p.value) <- mycolnames

    nobs<-tmp$nMat
    rownames(nobs) <- myrownames
    colnames(nobs) <- mycolnames

    LOD<-tmp$LODMat
    rownames(LOD) <- myrownames
    colnames(LOD) <- mycolnames

    retval <- new("LDdist",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LDdist", function(object, posVec, maxDist, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
           standardGeneric("LDdist"))

setMethod("LDdist", "geneSet", LDdist.geneSet)
